ImplicitTreapOfInt extension type

on
Implemented types

Constructors

ImplicitTreapOfInt.of(Iterable<int> items)

Properties

base ImplicitTreapBase<int, IntNode>
final
first int
Returns the first item in this treap.
no setterinherited
firstOrDefault int?
Returns the first item in this treap, or null if it is empty.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
last int
Returns the last item in this treap.
no setterinherited
lastOrDefault int?
Returns the last item in this treap, or null if it is empty.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The number of items in the treap.
no setterinherited
values Iterable<int>
Iterate over the items in the treap.
no setterinherited

Methods

add(int item) ImplicitTreapOfInt
Adds item to the end of the treap.
append(ImplicitTreapOfInt other) ImplicitTreapOfInt
Appends other to the end of this treap.
copy() ImplicitTreapOfInt
Creates a copy of this treap.
insert(int index, int item) ImplicitTreapOfInt
Inserts item at index.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(int index) ImplicitTreapOfInt
Removes the item at index.
skip(int count) ImplicitTreapOfInt
Skips the first count items and returns a new treap with the remaining items.
take(int count) ImplicitTreapOfInt
Returns a new treap with the first count items.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) int
Returns the item at index.
inherited